from zempy.zosapi.core.enum_base import ZosEnumBase


class SurfacePhaseSlopeData(ZosEnumBase):
    PhaseSlopeTangential = 0
    PhaseSlopeSagittal = 1
    PhaseSlopeX = 2
    PhaseSlopeY = 3
    PhaseSlopeModulus = 4
    PhaseSlopeUnused = 5

SurfacePhaseSlopeData._NATIVE_PATH = "ZOSAPI.Analysis.SurfacePhaseSlopeData"
SurfacePhaseSlopeData._ALIASES_EXTRA = {}

__all__ = ["SurfacePhaseSlopeData"]
